@@ -102,10 +102,10 @@ class Elastic(DataLayer):
         for resource, resource_config in app.config['DOMAIN'].items():
             datasource = resource_config.get('datasource', {})
 
-            if datasource.get('backend') != 'elastic': # only put mapping for elastic sources
+            if datasource.get('backend') != 'elastic':  # only put mapping for elastic sources
                 continue
 
-            if datasource.get('source', resource) != resource: # only put mapping for core types
+            if datasource.get('source', resource) != resource:  # only put mapping for core types
                 continue
 
             properties = {}
@@ -231,16 +231,19 @@ class Elastic(DataLayer):
         args['overwrite_existing'] = True
         return self.es.index(document=document, id=id_, **args)
 
-    def remove(self, resource, id_=None):
+    def remove(self, resource, lookup=None):
         args = self._es_args(resource)
-        if id_:
-            return self.es.delete(id=id_, refresh=True, **args)
-        else:
-            try:
+        try:
+            if lookup:
+                return self.es.delete(id=lookup.get('_id'), refresh=True, **args)
+            else:
                 query = {'query': {'match_all': {}}}
                 return self.es.delete_by_query(query=query, **args)
-            except es_exceptions.ElasticHttpNotFoundError:
-                return
+        except es_exceptions.ElasticHttpNotFoundError:
+            return
+
+    def is_empty(self, resource):
+        return self.es.count(resource, {}) == 0
 
     def _parse_hits(self, hits, resource):
         """Parse hits response into documents."""
